@@ -12,8 +12,8 @@ set -o nounset
 
 
 set -e
-nim c --boundChecks:on -x:on mosdepth.nim
-nim c -r tests/funcs.nim
+nim c --boundChecks:on -x:on -d:useSysAssert -d:useGcAssert --lineDir:on --debuginfo --mm:refc mosdepth.nim
+nim c -x:on --mm:refc -d:useSysAssert -d:useGcAssert --lineDir:on --debuginfo -r tests/funcs.nim
 set +e
 exe=./mosdepth
 bam=/data/human/NA12878.subset.bam
@@ -152,7 +152,7 @@ rm -f t.*
 
 #regions and global should not be the same when -b is specified
 run regions $exe t_regions -n -b 100 tests/empty-tids.bam 
-assert_equal $(diff -u t_regions.mosdepth.region.dist.txt t_regions.mosdepth.global.dist.txt | wc -l) 1447
+assert_equal $(diff -u t_regions.mosdepth.region.dist.txt t_regions.mosdepth.global.dist.txt | wc -l) 1436
 rm -f t_regions.*
 
 run overlappingPairs $exe t tests/overlapping-pairs.bam
